CatalogState

Struct CatalogState 

pub struct CatalogState {
    pub tables: HashMap<TableId, TableSchema>,
    pub databases: HashMap<DatabaseId, DatabaseSchema>,
    pub types: HashMap<TypeId, TypeSchema>,
    pub global_types: HashMap<TypeId, TypeSchema>,
    /* private fields */
}

Fields

tables: HashMap<TableId, TableSchema>

Contains the definitions of all tables, accessible through their unique, stable ID.

databases: HashMap<DatabaseId, DatabaseSchema>

Contains the definitions of all databases, accessible through their unique, stable ID.

types: HashMap<TypeId, TypeSchema>

Contains the definitions of all user-created types, accessible through their unique, stable ID.

global_types: HashMap<TypeId, TypeSchema>

Global built-in types (e.g. Option[T]). Populated at startup, never journaled. TypeIds use reserved values descending from u32::MAX.

Implementations

Source

impl CatalogState

pub fn get_type(&self, id: TypeId) -> Option<&TypeSchema>

Looks up a type by ID, checking user types then global types.

pub fn pk_path_name( &self, path: &[FieldId], table_schema: &TableSchema, ) -> String

Returns the dot-separated flat field name for a primary key path. e.g. [FieldId(1), FieldId(0)]"address.city".

pub fn tables_in_database( &self, database: &str, ) -> impl Iterator<Item = (TableId, &TableSchema)>

pub fn types_in_database( &self, database: &str, ) -> impl Iterator<Item = (TypeId, &TypeSchema)>